@@ -172,10 +172,14 @@ class Plot(object):
     print("PLOT: plot_grid ...")
 
     fig,ax=self._initfig(ax)
+    y=model.z
+    if zr:
+      y=model.z/model.x
 
-    ax.plot(model.x,model.z,marker="s",ms=0.03,linestyle="None",color=self.pcolors["gray"])
+    ax.plot(model.x,y,marker="s",ms=0.03,linestyle="None",color=self.pcolors["gray"])
+
+    if not zr: ax.semilogy()
 
-    ax.semilogy()
     ax.semilogx()
     self._dokwargs(ax,**kwargs)
 
@@ -335,7 +339,7 @@ class Plot(object):
     return self._closefig(fig)
 
   def plot_cont(self,model,values,label="value",zlog=True,grid=False,
-                zlim=[None,None],zr=True,clevels=None,clabels=None,contour=True,
+                zlim=[None,None],zr=True,cmap=None,clevels=None,clabels=None,contour=True,
                 extend="neither",oconts=None,acont=None,acontl=None,nbins=70,
                 bgcolor=None,cb_format="%.1f",scalexy=[1,1],patches=None,
                 rasterized=False,returnFig=False,fig=None,ax=None,movie=False,**kwargs):
@@ -363,6 +367,10 @@ class Plot(object):
       a 2D array with numeric values for the plotting. E.g. any 2D array
       of the :class:`~prodimopy.read.Data_ProDiMo` object.
 
+    cmap : str or :class:`matplotlib.colors.Colormap`
+      this is simply passed on to the contourf routine of matplotlib
+      see :func:`matplotlib.pyplot.contourf` for detail
+
     oconts : array_like(:class:`~prodimopy.plot.Contour`,ndim=1)
       list of :class:`~prodimopy.plot.Contour` objects which will be drawn
       as additional contour levels. See also the example at the top of the page.
@@ -454,16 +462,19 @@ class Plot(object):
     else:
       x=model.x*scalexy[0]
       y=np.copy(model.z)*scalexy[1]
-      y[:,0]=y[:,0]+0.05*scalexy[1]
+      # if one wants log scale on the y axis (height) avoid problems with
+      # z=0.0 in thee prodimo grid.
+      if zlog==True:
+        y[:,0]=y[:,0]+np.min(y[:,1])*scalexy[1]
       ax.set_ylabel("z [au]")
       ax.set_xlabel("r [au]")
 
     # zorder is needed in case if rasterized is true
 
     if grid:
-      CS=ax.contourf(pvals.T,levels=levels,extend=extend,zorder=-20,extent=(-0.5,model.nx-0.5,0.0,model.nz-1.0))
+      CS=ax.contourf(pvals.T,levels=levels,extend=extend,zorder=-20,extent=(-0.5,model.nx-0.5,0.0,model.nz-1.0),cmap=cmap)
     else:
-      CS=ax.contourf(x,y,pvals,levels=levels,extend=extend,zorder=-20,origin="image")
+      CS=ax.contourf(x,y,pvals,levels=levels,extend=extend,zorder=-20,origin="image",cmap=cmap)
 
     # This is the fix for the white lines between contour levels
     for c in CS.collections:
@@ -905,7 +916,7 @@ class Plot(object):
     return values,label,zlog,zlim,extend
 
   def plot_abuncont(self,model,species='O',rel2H=True,label=None,zlog=True,
-                zlim=[None,None],zr=True,clevels=None,clabels=None,contour=True,
+                zlim=[None,None],zr=True,cmap=None,clevels=None,clabels=None,contour=True,
                 extend="neither",oconts=None,acont=None,acontl=None,nbins=70,
                 bgcolor=None,cb_format="%.1f",scalexy=[1,1],patches=None,
                 rasterized=False,ax=None,movie=False,**kwargs):
@@ -951,13 +962,13 @@ class Plot(object):
     values,labelN,zlogN,zlimN,extendN=self._prepareAbunForPlot(model,species,label,rel2H,zlog,zlim,extend)
 
     return self.plot_cont(model,values,label=labelN,zlog=zlogN,
-                zlim=zlimN,zr=zr,clevels=clevels,clabels=clabels,contour=contour,
+                zlim=zlimN,zr=zr,cmap=cmap,clevels=clevels,clabels=clabels,contour=contour,
                 extend=extendN,oconts=oconts,acont=acont,acontl=acontl,nbins=nbins,
                 bgcolor=bgcolor,cb_format=cb_format,scalexy=scalexy,patches=patches,
                 rasterized=rasterized,nolog=True,ax=ax,movie=movie,**kwargs)
 
   def plot_abuncont_grid(self,model,speciesList=['e-','H2','CO',"H2O"],nrows=2,ncols=2,rel2H=True,label=None,zlog=True,
-                zlim=[None,None],zr=True,clevels=None,clabels=None,contour=True,
+                zlim=[None,None],zr=True,cmap=None,clevels=None,clabels=None,contour=True,
                 extend="neither",oconts=None,acont=None,acontl=None,nbins=70,
                 bgcolor=None,cb_format="%.1f",scalexy=[1,1],patches=None,
                 rasterized=False,**kwargs):
@@ -1015,7 +1026,7 @@ class Plot(object):
       values,labelG,zlogG,zlimG,extendG=self._prepareAbunForPlot(model,species,label,rel2H,zlog,zliml,extend)
 
       self.plot_cont(model,values,label=labelG,zlog=zlogG,
-                zlim=zlimG,zr=zr,clevels=clevels,clabels=clabels,contour=contour,
+                zlim=zlimG,zr=zr,cmap=cmap,clevels=clevels,clabels=clabels,contour=contour,
                 extend=extendG,oconts=oconts,acont=acont,acontl=acontl,nbins=nbins,
                 bgcolor=bgcolor,cb_format=cb_format,scalexy=scalexy,patches=patches,
                 rasterized=rasterized,fig=fig,ax=axes.flatten()[iax],nolog=True,**kwargs)
@@ -1026,11 +1037,12 @@ class Plot(object):
 
     return self._closefig(fig)
 
-  def plot_reaccont(self,model,chemana,rtype,level=1,showAbun=False,values=None,label=None,zlog=True,
-                zlim=[None,None],clevels=None,clabels=None,contour=True,
-                extend="neither",oconts=None,nbins=70,
-                bgcolor=None,cb_format="%.1f",patches=None,
-                rasterized=True,ax=None,**kwargs):
+  def plot_reaccont(self,model,chemana,rtype,level=1,showAbun=False,values=None,
+                    label=None,cmap=None,zlog=True,zlim=[None,None],
+                    clevels=None,clabels=None,contour=True,
+                    extend="neither",oconts=None,nbins=70,
+                    bgcolor=None,cb_format="%.1f",patches=None,
+                    rasterized=True,ax=None,**kwargs):
     '''
     Make a contour plot with the reactions numbers from chemanalyse on top.
     As spatial coordinates the indices of the spatial grid are used.
@@ -1100,7 +1112,7 @@ class Plot(object):
       kwargs["title"]=tit
 
     fig=self.plot_cont(model,values,label=label,zlog=zlog,grid=True,
-            zlim=zlim,zr=False,clevels=clevels,clabels=clabels,contour=contour,
+            zlim=zlim,zr=False,cmap=cmap,clevels=clevels,clabels=clabels,contour=contour,
             extend=extend,oconts=oconts,acont=None,acontl=None,nbins=nbins,
             bgcolor=bgcolor,cb_format=cb_format,scalexy=[1.0,1.0],patches=patches,
             rasterized=rasterized,nolog=True,ax=ax,movie=False,returnFig=True,**kwargs)
