@@ -398,7 +398,7 @@ class PlotModels(object):
       # ax.hlines(ygrid,xmin=ax.get_xlim()[0],xmax=ax.get_xlim()[1],linestyle="solid",linewidth=0.5,color="grey",zorder=100)
       ax.yaxis.grid(color="grey",zorder=-100)
 
-    ax.set_xticklabels(lticks,rotation='70',minor=False)
+    ax.set_xticklabels(lticks,rotation=70,minor=False)
     zed=[tick.label.set_fontsize(7) for tick in ax.xaxis.get_major_ticks()]
 
     self._legend(ax,**kwargs)
